##  Creating Transformations
You can create a single transformation or multiple transformations at once. To create a transformation, follow these steps:
  1. Navigate to the Transformation tab within the Initiative Fact Sheet. Click on New Transformation, which will open the Transformation template panel.
  2. Choose the needed template from the Transformation template panel. In the example shown below, we are introducing a new application.
  3. Fill in all the necessary fields in the template. In this instance, as we are introducing a new application, include details such as the application's name, the relevant Organization or region it is being introduced, the supported Business Capability, etc. Only the name of the Transformation is mandatory, and you can provide all other details later as well.
  4. Click Save.
![Creating Transformations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275050a57a441014aa26aae487b184d5_LowRes.gif)
Creating Transformations


With this, you have successfully created a Transformation item to introduce a new application. As an impact, a new Application Fact Sheet is created in your workspace.
You can review the implied impacts and include additional impacts to the Fact Sheets in the scope. By default, all implied impacts create a direct relation to model changes. However, it's also possible to change this and use the “active from/until” field on the relation for added flexibility.
